@@ -140,11 +140,13 @@ present for backward compatibility."
   (add-to-list 'tramp-default-method-alist
 	       (list "\\`ftp\\." nil tramp-efs-method))
   (add-to-list 'tramp-default-method-alist
-	       (list nil "\\`\\(anonymous\\|ftp\\)\\'" tramp-efs-method))
+	       (list nil "\\`\\(anonymous\\|ftp\\)\\'" tramp-efs-method)))
 
+(when (featurep 'xemacs)
   ;; Add all XEmacs download sites to `tramp-default-method-alist'.
   ;; The settings above should be sufficient, but it's better to make
   ;; it explicitly.
+  (defvar package-get-download-sites) ; Pacify compiler.
   (when (listp package-get-download-sites)
     (mapcar (lambda (x)
 	      (when (listp x)
